documentFactory.LocateDocumentStream

|  | ## Cheshire3 Object Model: Class LocateDocumentStream

Module documentFactory :: Class LocateDocumentStream

## Class LocateDocumentStream
source code

Object Tree:

    BaseDocumentStream --+
                         |
    MultipleDocumentStream --+
                             |
       DirectoryDocumentStream --+
                                 |
                                LocateDocumentStream

Instance Methods

find_documents(self, session, cache=0)
Inherited from `MultipleDocumentStream`: `__init__` Inherited from `MultipleDocumentStream` (private): `_fetchName`, `_fetchStream`, `_processFile`, `_processFiles` Inherited from `BaseDocumentStream`: `fetch_document`, `open_stream`

Class Variables

Inherited from `BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### find_documents(self, session, cache=0) | source code
Overrides: DirectoryDocumentStream.find_documents